diff options
| author | Raphael Collet <rco@odoo.com> | 2018-01-11 13:52:13 +0100 |
|---|---|---|
| committer | Raphael Collet <rco@odoo.com> | 2018-01-11 13:52:16 +0100 |
| commit | 309b6b8e5ab476de6f432bbf64939a72af85be3b (patch) | |
| tree | 1de743a371e14d3ea8c3260693531dc086a5e6e8 /addons/web/static/src/js/views/basic | |
| parent | 0474de44c03d039c29e34243d55f11fee12c454d (diff) | |
[FIX] api: optimize odoo.api.Cache.get_records()
Assuming that `field.cache_key(record)` is independent from `record.id`,
compute the cache key once for all records, and avoid using `browse` on all
record ids. This makes `get_records` about 20 times faster.
This has a good performance impact on `field.modified_draft()`, which is used
during onchanges for invalidating fields.
Diffstat (limited to 'addons/web/static/src/js/views/basic')
0 files changed, 0 insertions, 0 deletions
